@@ -1,5 +1,5 @@
 import unittest
-from nakametpy.thermo import potential_temperature
+from src.thermo import potential_temperature # For Travis CI src.thermo is Right not ..src.thermo or .src.thermo
 
 class ThermoTest(unittest.TestCase):
     def test_theta(self):
